/*
 * yeti_gsl.i --
 *
 *	Support for GSL (GNU Scientific Library) in Yeti.
 *
 *-----------------------------------------------------------------------------
 *
 *	Copyright (C) 2005 Eric THIEBAUT.
 *
 *	This file is part of Yeti.
 *	
 *	Yeti is  free software;  you can redistribute  it and/or  modify it
 *	under the terms  of the GNU General Public  License as published by
 *	the Free Software  Foundation; either version 2 of  the License, or
 *	(at your option) any later version.
 *	
 *	Yeti is distributed in the hope that it will be useful, but WITHOUT
 *	ANY WARRANTY; without even  the implied warranty of MERCHANTABILITY
 *	or FITNESS  FOR A PARTICULAR  PURPOSE.  See the GNU  General Public
 *	License for more details.
 *	
 *	You should have  received a copy of the  GNU General Public License
 *	along with  Yeti (file "COPYING"  in the top source  directory); if
 *	not, write to the Free  Software Foundation, Inc., 59 Temple Place,
 *	Suite 330,  Boston, MA  02111-1307 USA.
 *
 *-----------------------------------------------------------------------------
 *
 * History:
 *	$Id$
 *	$Log$
 */

if (is_func(plug_in)) plug_in, "yeti_gsl";

local gsl_sf;
/* DOCUMENT gsl_sf
 *   Special functions from GSL (GNU Scientific Library).
 *
 *   Airy functions:
 *     gsl_sf_airy_Ai - 
 *   Bessel functions:
 *     gsl_sf_bessel_J0 - regular cylindrical Bessel functions
 *     gsl_sf_bessel_Y0 - irregular cylindrical Bessel functions
 *     gsl_sf_bessel_I0 - regular modified cylindrical Bessel functions
 *     gsl_sf_bessel_K0 - irregular modified cylindrical Bessel functions
 *     gsl_sf_bessel_j0 - regular spherical Bessel functions
 *     gsl_sf_bessel_y0 - irregular spherical Bessel functions
 *     gsl_sf_bessel_i0_scaled - regular modified spherical Bessel functions
 *     gsl_sf_bessel_k0_scaled - irregular modified spherical Bessel functions
 *   Clausen Functions: gsl_sf_clausen
 *
 * SEE ALSO:
 */

extern gsl_sf_airy_Ai;
extern gsl_sf_airy_Bi;
extern gsl_sf_airy_Ai_scaled;
extern gsl_sf_airy_Bi_scaled;
extern gsl_sf_airy_Ai_deriv;
extern gsl_sf_airy_Bi_deriv;
extern gsl_sf_airy_Ai_deriv_scaled;
extern gsl_sf_airy_Bi_deriv_scaled;
/* DOCUMENT gsl_sf_airy_Ai(x [,flags])
 *          gsl_sf_airy_Bi(x [,flags])
 *          gsl_sf_airy_Ai_deriv(x [,flags])
 *          gsl_sf_airy_Bi_deriv(x [,flags])
 *          gsl_sf_airy_Ai_scaled(x [,flags])
 *          gsl_sf_airy_Bi_scaled(x [,flags])
 *          gsl_sf_airy_Ai_deriv_scaled(x [,flags])
 *          gsl_sf_airy_Bi_deriv_scaled(x [,flags])
 *
 *   These routines compute the Airy functions and derivatives for the
 *   argument X (a non-complex numerical array).
 *
 *   The routines gsl_sf_airy_Ai and gsl_sf_airy_Bi compute Airy functions
 *   Ai(x) and Bi(x) which are defined by the integral representations:
 *
 *      Ai(x) = (1/PI) \int_0^\infty cos((1/3)*t^3 + x*t) dt
 *      Bi(x) = (1/PI) \int_0^\infty (exp(-(1/3)*t^3)
 *                                    + sin((1/3)*t^3 + x*t)) dt
 *
 *   The routines gsl_sf_airy_Ai_deriv and gsl_sf_airy_Bi_deriv compute
 *   the derivatives of the Airy functions.
 *
 *   The routines gsl_sf_airy_Ai_scaled and gsl_sf_airy_Bi_scaled compute
 *   a scaled version of the Airy functions S_A(x) Ai(x) and S_B(x) Bi(x).
 *   The scaling factors are:
 *      S_A(x) = exp(+(2/3)*x^(3/2)), for x>0
 *               1,                   for x<0;
 *      S_B(x) = exp(-(2/3)*x^(3/2)), for x>0
 *               1,                   for x<0.
 *
 *   The routines gsl_sf_airy_Ai_deriv_scaled and
 *   gsl_sf_airy_Bi_deriv_scaled compute the derivatives of the scaled Airy
 *   functions.
 *
 *   The optional FLAGS argument is a bitwise combination which specifies
 *   the relative accuracy of the result and if an estimate of the error
 *   is required:
 *
 *     (FLAGS & 1) is non-zero to compute an estimate of the error, the
 *         result, says Y, has an additional dimension of length 2
 *         prepended to the dimension list of X:
 *             Y(1,..) = value of F(X)
 *             Y(2,..) = error estimate for the value of F(X)
 *
 *     (FLAGS & 6) is the accuracy mode:
 *         6 - Double-precision (GSL_PREC_DOUBLE), a relative accuracy of
 *             approximately 2e-16.
 *         4 - Single-precision (GSL_PREC_SINGLE), a relative accuracy of
 *             approximately 1e-7.
 *         2 - Approximate values (GSL_PREC_APPROX), a relative accuracy
 *             of approximately 5e-4.
 *         0 - Default accuracy (GSL_PREC_DOUBLE).
 *
 *   For instance, with FLAGS=1, function values are computed with relative
 *   accuracy of 2e-16 and an estimate of the error is returned; with
 *   FLAGS=2, approximate values with relative accuracy of 5e-4 are
 *   returned without error estimate
 *
 *
 * SEE ALSO: gsl_sf.
 */

extern gsl_sf_bessel_J0;
extern gsl_sf_bessel_J1;
extern gsl_sf_bessel_Jn;
extern gsl_sf_bessel_Jnu;
/* DOCUMENT gsl_sf_bessel_J0(x [,err])
 *          gsl_sf_bessel_J1(x [,err])
 *          gsl_sf_bessel_Jn(n, x [,err])
 *          gsl_sf_bessel_Jnu(nu, x [,err])
 *
 *   These functions compute the regular cylindrical Bessel functions for
 *   argument X (a non-complex numerical array or scalar) and of various
 *   order: zeroth order, J_0(x); first order, J_1(x), integer order order
 *   N, J_n(x), and fractional order NU, J_nu(x).  N must be a scalar
 *   integer and NU a scalar real.
 *
 *   If optional argument ERR is true, these fucntions also compute an
 *   estimate of the error, the result, says Y, has an additional dimension
 *   of length 2 prepended to the dimension list of X:
 *       Y(1,..) = value of F(X)
 *       Y(2,..) = error estimate for the value of F(X)
 *    
 * SEE ALSO: gsl_sf_bessel_Y0, gsl_sf_bessel_I0, gsl_sf_bessel_K0,
 *           gsl_sf_bessel_j0, gsl_sf_bessel_y0, gsl_sf_bessel_i0,
 *           gsl_sf_bessel_k0.
 */

extern gsl_sf_bessel_Y0;
extern gsl_sf_bessel_Y1;
extern gsl_sf_bessel_Yn;
extern gsl_sf_bessel_Ynu;
/* DOCUMENT gsl_sf_bessel_Y0(x [,err])
 *          gsl_sf_bessel_Y1(x [,err])
 *          gsl_sf_bessel_Yn(n, x [,err])
 *          gsl_sf_bessel_Ynu(nu, x [,err])
 *
 *   These functions compute the irregular cylindrical Bessel functions
 *   for X>0.  See gsl_sf_bessel_J0 for a more detailled description.
 *    
 * SEE ALSO: gsl_sf_bessel_J0.
 */

extern gsl_sf_bessel_I0;
extern gsl_sf_bessel_I1;
extern gsl_sf_bessel_In;
extern gsl_sf_bessel_Inu;
extern gsl_sf_bessel_I0_scaled;
extern gsl_sf_bessel_I1_scaled;
extern gsl_sf_bessel_In_scaled;
extern gsl_sf_bessel_Inu_scaled;
/* DOCUMENT gsl_sf_bessel_I0(x [,err])
 *          gsl_sf_bessel_I1(x [,err])
 *          gsl_sf_bessel_In(n, x [,err])
 *          gsl_sf_bessel_Inu(nu, x [,err])
 *          gsl_sf_bessel_I0_scaled(x [,err])
 *          gsl_sf_bessel_I1_scaled(x [,err])
 *          gsl_sf_bessel_In_scaled(n, x [,err])
 *          gsl_sf_bessel_Inu_scaled(nu, x [,err])
 *
 *   These routines compute the regular modified cylindrical Bessel
 *   functions and their scaled counterparts.  The scaling factor is
 *   exp(-abs(X)); for instance: I0_scaled(X) = exp(-abs(X))*I0(X).
 *   See gsl_sf_bessel_J0 for a more detailled description.
 *
 * SEE ALSO: gsl_sf_bessel_J0.
 */

extern gsl_sf_bessel_K0;
extern gsl_sf_bessel_K1;
extern gsl_sf_bessel_Kn;
extern gsl_sf_bessel_Knu;
extern gsl_sf_bessel_lnKnu;
extern gsl_sf_bessel_K0_scaled;
extern gsl_sf_bessel_K1_scaled;
extern gsl_sf_bessel_Kn_scaled;
extern gsl_sf_bessel_Knu_scaled;
/* DOCUMENT gsl_sf_bessel_K0(x [,err])
 *          gsl_sf_bessel_K1(x [,err])
 *          gsl_sf_bessel_Kn(n, x [,err])
 *          gsl_sf_bessel_Knu(nu, x [,err])
 *          gsl_sf_bessel_lnKnu(nu, x [,err])
 *          gsl_sf_bessel_K0_scaled(x [,err])
 *          gsl_sf_bessel_K1_scaled(x [,err])
 *          gsl_sf_bessel_Kn_scaled(n, x [,err])
 *          gsl_sf_bessel_Knu_scaled(nu, x [,err])
 *
 *   These routines compute the irregular modified cylindrical Bessel
 *   functions and their scaled counterparts.  The scaling factor is exp(X)
 *   for X>0; for instance: K0_scaled(X) = exp(X)*K0(X).  The function
 *   gsl_sf_bessel_lnKnu computes the logarithm of the irregular modified
 *   Bessel function of fractional order NU.  See gsl_sf_bessel_J0 for a
 *   more detailled description.
 *
 * SEE ALSO: gsl_sf_bessel_J0.
 */

extern gsl_sf_bessel_j0;
extern gsl_sf_bessel_j1;
extern gsl_sf_bessel_j2;
extern gsl_sf_bessel_jl;
/* DOCUMENT gsl_sf_bessel_j0(x [,err])
 *          gsl_sf_bessel_j1(x [,err])
 *          gsl_sf_bessel_j2(x [,err])
 *          gsl_sf_bessel_jl(l, x [,err])
 *
 *   These routines compute the regular spherical Bessel functions of zeroth
 *   order (j0), first order (j1), second order (j2) and l-th order (jl,
 *   for X>=0 and L>=0).  See gsl_sf_bessel_J0 for a more detailled
 *   description.
 *
 * SEE ALSO: gsl_sf_bessel_J0.
 */

extern gsl_sf_bessel_y0;
extern gsl_sf_bessel_y1;
extern gsl_sf_bessel_y2;
extern gsl_sf_bessel_yl;
/* DOCUMENT gsl_sf_bessel_y0(x [,err])
 *          gsl_sf_bessel_y1(x [,err])
 *          gsl_sf_bessel_y2(x [,err])
 *          gsl_sf_bessel_yl(l, x [,err])
 *
 *   These routines compute the irregular spherical Bessel functions of
 *   zeroth order (y0), first order (y1), second order (y2) and l-th order
 *   (yl, for L>=0):
 *
 *     y0(x) = -cos(x)/x
 *     y1(x) = -(cos(x)/x + sin(x))/x
 *     y2(x) = (-3/x^3 + 1/x)*cos(x) - (3/x^2)*sin(x)
 *
 *   See gsl_sf_bessel_J0 for a more detailled description of the arguments.
 *
 *
 * SEE ALSO: gsl_sf_bessel_J0.
 */

extern gsl_sf_bessel_i0_scaled;
extern gsl_sf_bessel_i1_scaled;
extern gsl_sf_bessel_i2_scaled;
extern gsl_sf_bessel_il_scaled;
/* DOCUMENT gsl_sf_bessel_i0_scaled(x [,err])
 *          gsl_sf_bessel_i1_scaled(x [,err])
 *          gsl_sf_bessel_i2_scaled(x [,err])
 *          gsl_sf_bessel_il_scaled(l, x [,err])
 *
 *   These routines compute the regular modified spherical Bessel functions
 *   of zeroth order (i0), first order (i1), second order (i2) and l-th
 *   order (il):
 *
 *     il_scaled(x) = exp(-abs(x))*il(x)
 *
 *   The regular modified spherical Bessel functions i_l(x) are related to
 *   the modified Bessel functions of fractional order by:
 *
 *     i_l(x) = sqrt(PI/(2*x))*I_{l + 1/2}(x)
 *
 *   See gsl_sf_bessel_J0 for a more detailled description of the arguments.
 *
 *
 * SEE ALSO: gsl_sf_bessel_J0.
 */

extern gsl_sf_bessel_k0_scaled;
extern gsl_sf_bessel_k1_scaled;
extern gsl_sf_bessel_k2_scaled;
extern gsl_sf_bessel_kl_scaled;
/* DOCUMENT gsl_sf_bessel_k0_scaled(x [,err])
 *          gsl_sf_bessel_k1_scaled(x [,err])
 *          gsl_sf_bessel_k2_scaled(x [,err])
 *          gsl_sf_bessel_kl_scaled(l, x [,err])
 *
 *   These routines compute the irregular modified spherical Bessel
 *   functions of zeroth order (k0), first order (k1), second order (k2)
 *   and l-th order (kl), for X>0:
 *
 *     kl_scaled(x) = exp(x)*kl(x)
 *
 *   The irregular modified spherical Bessel functions i_l(x) are related to
 *   the modified Bessel functions of fractional order by:
 *
 *     k_l(x) = sqrt(PI/(2*x))*K_{l + 1/2}(x)
 *
 *   See gsl_sf_bessel_J0 for a more detailled description of the arguments.
 *
 *
 * SEE ALSO: gsl_sf_bessel_J0.
 */

extern gsl_sf_clausen;
/* DOCUMENT gsl_sf_clausen(x [,err])
 *   Returns the Clausen function Cl_2 of its argument X.
 *
 * SEE ALSO: gsl_sf
 */

extern gsl_sf_dawson;
/* DOCUMENT gsl_sf_dawson(x [,err])
 *   Returns the Dawson integral of its argument X defined by:
 *    exp(-x^2) \int_0^x exp(t^2) dt
 *
 * SEE ALSO: gsl_sf
 */

extern gsl_sf_debye_1;
extern gsl_sf_debye_2;
extern gsl_sf_debye_3;
extern gsl_sf_debye_4;
extern gsl_sf_ellint_Kcomp;
extern gsl_sf_ellint_Ecomp;
extern gsl_sf_dilog;

extern gsl_sf_erf;
extern gsl_sf_erfc;
extern gsl_sf_log_erfc;
extern gsl_sf_erf_Z;
extern gsl_sf_erf_Q;
extern gsl_sf_hazard;

extern gsl_sf_exp;
extern gsl_sf_expm1;
extern gsl_sf_exprel;
extern gsl_sf_exprel_2;
extern gsl_sf_exprel_n;

extern gsl_sf_expint_E1;
extern gsl_sf_expint_E2;
extern gsl_sf_expint_Ei;
extern gsl_sf_expint_3;
extern gsl_sf_Shi;
extern gsl_sf_Chi;
extern gsl_sf_Si;
extern gsl_sf_Ci;
extern gsl_sf_atanint;

extern gsl_sf_fermi_dirac_m1;
extern gsl_sf_fermi_dirac_0;
extern gsl_sf_fermi_dirac_1;
extern gsl_sf_fermi_dirac_2;
extern gsl_sf_fermi_dirac_mhalf;
extern gsl_sf_fermi_dirac_half;
extern gsl_sf_fermi_dirac_3half;
extern gsl_sf_fermi_dirac_int;

extern gsl_sf_gamma;
extern gsl_sf_lngamma;
extern gsl_sf_gammastar;
extern gsl_sf_gammainv;
extern gsl_sf_taylorcoeff;

extern gsl_sf_lambert_W0;
extern gsl_sf_lambert_Wm1;

extern gsl_sf_legendre_P1;
extern gsl_sf_legendre_P2;
extern gsl_sf_legendre_P3;
extern gsl_sf_legendre_Pl;

extern gsl_sf_legendre_Q0;
extern gsl_sf_legendre_Q1;
extern gsl_sf_legendre_Ql;

extern gsl_sf_log;
extern gsl_sf_log_abs;
extern gsl_sf_log_1plusx;
extern gsl_sf_log_1plusx_mx;

extern gsl_sf_synchrotron_1;
extern gsl_sf_synchrotron_2;

extern gsl_sf_transport_2;
extern gsl_sf_transport_3;
extern gsl_sf_transport_4;
extern gsl_sf_transport_5;

extern gsl_sf_sin;
extern gsl_sf_cos;
extern gsl_sf_sinc;
extern gsl_sf_lnsinh;
extern gsl_sf_lncosh;

extern gsl_sf_zeta;
extern gsl_sf_zetam1;
extern gsl_sf_eta;


  
